use std::error::Error;
use std::fs;
use std::fs::File;
use serde::{Serialize, Deserialize};
use std::path::PathBuf;

#[derive(Serialize, Deserialize, Debug)]
pub struct ManifestFile {
    pub version: u8,
    pub name: String,
}

impl ManifestFile {
    pub fn from(name: String) -> ManifestFile {
        return ManifestFile { version: 1, name }
    }

    pub fn read(path: &PathBuf) -> Result<ManifestFile, Box<dyn Error>> {
        let file = File::open(path)?;

        let data: ManifestFile = serde_yaml::from_reader(file)?;

        Ok(data)
    }

    pub fn write(&self, path: &PathBuf) -> Result<bool, Box<dyn Error>> {
        if path.exists() {
            fs::remove_file(path)?;
        }

        let file = File::create(path)?;

        serde_yaml::to_writer(file, self)?;

        Ok(true)
    }
}
