use std::panic;
use clap::{Parser, Subcommand};

#[derive(Parser, Debug)]
#[command(author, version, about, long_about = None)]
struct Arguments {
    #[command(subcommand)]
    command: Command
}

#[derive(Subcommand, Debug)]
enum Command {
    Init(command_init::Arguments),
    Name(command_name::Arguments),
}

fn main() {
    let arguments = Arguments::parse();

    // TODO: Remove panics and use Results instead.
    let result = panic::catch_unwind(|| {
        match &arguments.command {
            Command::Init(arguments) => { command_init::execute(arguments) },
            Command::Name(arguments) => { command_name::execute(arguments) },
        }
    });

    match result {
        Ok(_) => {}
        Err(err) => {
            if let Some(s) = err.downcast_ref::<&str>() {
                println!("Panic occurred with message: {}", s);
            } else {
                println!("Panic occurred with unknown payload.");
            }
        }
    }
}
